# -*- coding: utf-8 -*-

"""Tests using as library"""


import pytest
from conftest import cd

import abimap
from abimap import symver


def test_unitialized_all_global_symbols():
    m = symver.Map()

    expected = "Map not checked, run check()"
    symbols = None

    with pytest.raises(Exception) as e:
        symbols = m.all_global_symbols()
        assert expected in str(e.value)

    assert not symbols


def test_unitialized_guess_latest_release():
    m = symver.Map()

    expected = "Map not checked, run check()"
    symbols = None

    with pytest.raises(Exception) as e:
        symbols = m.guess_latest_release()
        assert expected in str(e.value)

    assert not symbols


def test_unitialized_sort_releases_nice():
    m = symver.Map()

    expected = "Map not checked, run check()"
    symbols = None

    with pytest.raises(Exception) as e:
        symbols = m.sort_releases_nice(None)
        assert expected in str(e.value)

    assert not symbols


def test_empty_map(datadir):
    m = symver.Map()

    expected = "Empty map"

    with pytest.raises(Exception) as e:
        m.check()
        assert expected in str(e.value)

    with cd(datadir):
        m.read("base.map")

        m.check()

        out = str(m)

        with open("empty_map.stdout") as tcout:
            assert out == tcout.read()


def test_guess_name_without_version(datadir):

    m = symver.Map()

    expected = "".join(["Insufficient information to guess the new release",
                        " name. Releases found do not have version",
                        " information or a valid library name. Please",
                        " provide the complete name of the release."])

    with cd(datadir):
        with pytest.raises(Exception) as e:
            m.read("without_version.map")
            m.guess_name(None, guess=True)

            assert expected in str(e.value)


def test_guess_name_without_prefix(datadir):

    m = symver.Map()
    expected = "".join(["Insufficient information to guess the new release",
                        " name. Releases found do not have version",
                        " information or a valid library name. Please",
                        " provide the complete name of the release."])

    with cd(datadir):
        with pytest.raises(Exception) as e:
            m.read("without_prefix.map")
            m.guess_name(None, guess=True)

            assert expected in str(e.value)


def test_guess_name_without_similar_prefix(datadir):

    m = symver.Map()

    with cd(datadir):
        m.read("without_similar_prefix.map")
        name = m.guess_name(None, guess=True)

        # It is expected the name to use the latest release prefix
        assert name == "UNRELATED_NAME_1_2_0"


def test_released_map(datadir):
    m = symver.Map()

    with cd(datadir):
        m.read("released.map")

        m.check()

        r = m.releases[0]

        assert r.released


def test_print_released_map(datadir):
    m = symver.Map()

    with cd(datadir):
        m.read("base.map")

        m.check()

        r = m.releases[0]

        r.released = True

        out = str(m)

        with open("print_released.stdout") as tcout:
            assert out == tcout.read()


def test_version_different_program_names(capsys):
    class C(object):
        """
        Empty class used as a namespace
        """
        pass

    # Get the arguments parser
    parser = symver.get_arg_parser()

    # Set the options to call the version subcommand
    options = ['version']

    # Create a namespace and set a custom program name
    ns = C()
    ns.program = 'someapp'

    # Parse arguments
    args = parser.parse_args(options, namespace=ns)

    # Run command and check output
    ns.func(args)
    out, err = capsys.readouterr()
    assert out == "someapp-{0}\n".format(abimap.__version__)
    assert not err

    # Create a namespace and set an empty program name
    ns = C()
    ns.program = None

    # Parse arguments
    args = parser.parse_args(options, namespace=ns)

    # Run command and check output
    ns.func(args)
    out, err = capsys.readouterr()
    assert out == "abimap-{0}\n".format(abimap.__version__)
    assert not err


def test_new_different_program_name(datadir, capsys):
    class C(object):
        """
        Empty class used as a namespace
        """
        pass

    with cd(datadir):
        # Get the arguments parser
        parser = symver.get_arg_parser()

        # Set the options to call the version subcommand
        options = ['new', '-r', 'different_name_1_0_0', '-i', 'symbol.in']

        # Create a namespace and set a custom program name
        ns = C()
        ns.program = 'someapp'

        # Parse arguments
        args = parser.parse_args(options, namespace=ns)

        # Run command and check output
        ns.func(args)
        out, err = capsys.readouterr()
        with open("new_different_name.stdout") as tcout:
            assert out == tcout.read()
        assert not err

        # Create a namespace and set an empty program name
        ns = C()
        ns.program = None

        # Parse arguments
        args = parser.parse_args(options, namespace=ns)

        # Run command and check output
        ns.func(args)
        out, err = capsys.readouterr()
        with open("new_default_name.stdout") as tcout:
            assert out == tcout.read()
        assert not err


def test_update_different_program_name(datadir, capsys):
    class C(object):
        """
        Empty class used as a namespace
        """
        pass

    with cd(datadir):
        # Get the arguments parser
        parser = symver.get_arg_parser()

        # Set the options to call the version subcommand
        options = ['update', '-a', '-i', 'symbol.in', "base.map"]

        # Create a namespace and set a custom program name
        ns = C()
        ns.program = 'someapp'

        # Parse arguments
        args = parser.parse_args(options, namespace=ns)

        # Run command and check output
        ns.func(args)
        out, err = capsys.readouterr()
        with open("update_different_name.stdout") as tcout:
            assert out == tcout.read()
        assert not err

        # Create a namespace and set an empty program name
        ns = C()
        ns.program = None

        # Parse arguments
        args = parser.parse_args(options, namespace=ns)

        # Run command and check output
        ns.func(args)
        out, err = capsys.readouterr()
        with open("update_default_name.stdout") as tcout:
            assert out == tcout.read()
        assert not err



# -*- coding: utf-8 -*-

import os
import sys

here = os.path.abspath(os.path.dirname(__file__))

# Add src directory to path so we can import the package
sys.path.insert(0, os.path.join(here, 'src'))

try:
    from abimap._version import __version__
    version = __version__
except ImportError:
    # Fallback to reading file directly
    _locals = {}
    with open(os.path.join(here, 'src', 'abimap', '_version.py')) as fp:
        exec(fp.read(), None, _locals)
    version = _locals["__version__"]

def get_version():
    """
    Print and return the version based on _version.py

    :returns: abimap current version
    """

    print(version)

    return version


def get_name_version():
    """
    Print and return the name and version based on _version.py

    :returns: abimap name and version
    """

    name_version = "abimap-" + version

    print (name_version)

    return name_version


if __name__ == "__main__":
    get_name_version()



#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""The setup script."""

import os
from glob import glob
from os.path import basename
from os.path import splitext

from setuptools import find_packages
from setuptools import setup

package_name = "abimap"
here = os.path.abspath(os.path.dirname(__file__))

with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

setup(
    author="Anderson Toshiyuki Sasaki",
    author_email='ansasaki@redhat.com',
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'Natural Language :: English',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
        'Programming Language :: Python :: 3.11',
        'Programming Language :: Python :: 3.12',
        'Programming Language :: Python :: 3.13',
    ],
    description="A helper for library maintainers to use symbol versioning ",
    long_description=readme + '\n\n' + history,
    include_package_data=True,
    keywords='symver abimap symbol version versioning linker script library maintenance',
    name=package_name,
    packages=find_packages('src'),
    package_dir={'': 'src'},
    py_modules=[splitext(basename(path))[0] for path in glob(
        os.path.join(here, 'src', 'abimap', '*.py'))],
    entry_points={
        'console_scripts': ['abimap=abimap.main:main']
    },
    url='https://github.com/ansasaki/abimap',
    zip_safe=False,
)



# -*- coding: utf-8 -*-

"""Tests for update command"""

import pytest
from conftest import run_tc


@pytest.mark.skipif(pytest.__version__ < '3.4', reason="caplog not supported")
def test_update(testcases, datadir, capsys, caplog):
    for tc in testcases:
        run_tc(tc, datadir, capsys, caplog)
